.. image:: https://travis-ci.org/ambitioninc/ambition-python.png
   :target: https://travis-ci.org/ambitioninc/ambition

.. image:: https://coveralls.io/repos/ambitioninc/ambition-python/badge.png?branch=develop
    :target: https://coveralls.io/r/ambitioninc/ambition?branch=develop

.. image:: https://pypip.in/v/ambition/badge.png
    :target: https://pypi.python.org/pypi/ambition/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/ambition/badge.png
    :target: https://pypi.python.org/pypi/ambition/
    :alt: Number of PyPI downloads

ambition
===============

Installation
------------
To install the latest release, type::

    pip install ambition

To install the latest code directly from source, type::

    pip install git+git://github.com/ambitioninc/ambition.git

Documentation
=============

Full documentation is available at http://ambition.readthedocs.org

License
=======
MIT License (see LICENSE)
